Index: sbin/gpt/destroy.c
===================================================================
RCS file: /cvsroot/src/sbin/gpt/destroy.c,v
retrieving revision 1.13
diff -p -u -r1.13 destroy.c
--- sbin/gpt/destroy.c	16 Oct 2019 19:03:53 -0000	1.13
+++ sbin/gpt/destroy.c	28 May 2022 11:40:06 -0000
@@ -59,7 +59,7 @@ struct gpt_cmd c_destroy = {
 	"destroy",
 	cmd_destroy,
 	destroyhelp, __arraycount(destroyhelp),
-	GPT_SYNC,
+	GPT_SYNC | GPT_OPTIONAL,
 };
 
 #define usage() gpt_usage(NULL, &c_destroy)
Index: sbin/gpt/gpt.c
===================================================================
RCS file: /cvsroot/src/sbin/gpt/gpt.c,v
retrieving revision 1.82
diff -p -u -r1.82 gpt.c
--- sbin/gpt/gpt.c	24 May 2020 18:42:20 -0000	1.82
+++ sbin/gpt/gpt.c	28 May 2022 11:40:06 -0000
@@ -430,14 +430,18 @@ gpt_gpt(gpt_t gpt, off_t lba, int found)
 
 	m = map_add(gpt, lba, 1, (lba == 1)
 	    ? MAP_TYPE_PRI_GPT_HDR : MAP_TYPE_SEC_GPT_HDR, hdr, 1);
-	if (m == NULL)
-		return (-1);
+	if (m == NULL) {
+		if ((gpt->flags & GPT_OPTIONAL) == 0)
+			return (-1);
+	}
 
 	m = map_add(gpt, (off_t)le64toh((uint64_t)hdr->hdr_lba_table),
 	    (off_t)blocks,
 	    lba == 1 ? MAP_TYPE_PRI_GPT_TBL : MAP_TYPE_SEC_GPT_TBL, p, 1);
-	if (m == NULL)
-		return (-1);
+	if (m == NULL) {
+		if ((gpt->flags & GPT_OPTIONAL) == 0)
+			return (-1);
+	}
 
 	if (lba != 1)
 		return (1);
@@ -460,8 +464,11 @@ gpt_gpt(gpt_t gpt, off_t lba, int found)
 		}
 		m = map_add(gpt, (off_t)le64toh((uint64_t)ent->ent_lba_start),
 		    size, MAP_TYPE_GPT_PART, ent, 0);
-		if (m == NULL)
-			return (-1);
+		if (m == NULL) {
+			if ((gpt->flags & GPT_OPTIONAL) == 0)
+				return (-1);
+			break;
+		}
 		m->map_index = i + 1;
 	}
 	return (1);
Index: sbin/gpt/gpt.h
===================================================================
RCS file: /cvsroot/src/sbin/gpt/gpt.h,v
retrieving revision 1.42
diff -p -u -r1.42 gpt.h
--- sbin/gpt/gpt.h	24 May 2020 18:42:20 -0000	1.42
+++ sbin/gpt/gpt.h	28 May 2022 11:40:06 -0000
@@ -85,6 +85,7 @@ gpt_t	gpt_open(const char *, int, int, o
 #define GPT_TIMESTAMP	0x20
 #define GPT_SYNC	0x40
 #define GPT_HYBRID	0x80
+#define GPT_OPTIONAL	0x4000
 #define GPT_OPTDEV      0x8000
 
 void*	gpt_read(gpt_t, off_t, size_t);
Index: sbin/gpt/map.c
===================================================================
RCS file: /cvsroot/src/sbin/gpt/map.c,v
retrieving revision 1.15
diff -p -u -r1.15 map.c
--- sbin/gpt/map.c	24 May 2020 14:42:44 -0000	1.15
+++ sbin/gpt/map.c	28 May 2022 11:40:06 -0000
@@ -110,13 +110,13 @@ map_add(gpt_t gpt, off_t start, off_t si
 	while (n != NULL && n->map_start + n->map_size <= start)
 		n = n->map_next;
 	if (n == NULL) {
-		if (!(gpt->flags & GPT_QUIET))
+		if (!(gpt->flags & (GPT_QUIET|GPT_OPTIONAL)))
 			gpt_warnx(gpt, "Can't find map");
 		return NULL;
 	}
 
 	if (n->map_start + n->map_size < start + size) {
-		if (!(gpt->flags & GPT_QUIET))
+		if (!(gpt->flags & (GPT_QUIET|GPT_OPTIONAL)))
 			gpt_warnx(gpt, "map entry doesn't fit media: "
 			    "new start + new size < start + size\n"
 			    "(%jx + %jx < %jx + %jx)",
@@ -143,8 +143,9 @@ map_add(gpt_t gpt, off_t start, off_t si
 	if (n->map_type != MAP_TYPE_UNUSED) {
 		if (n->map_type != MAP_TYPE_MBR_PART ||
 		    type != MAP_TYPE_GPT_PART) {
-			gpt_warnx(gpt, "bogus map current=%s new=%s",
-			    map_type(n->map_type), map_type(type));
+			if (!(gpt->flags & GPT_OPTIONAL))
+				gpt_warnx(gpt, "bogus map current=%s new=%s",
+				    map_type(n->map_type), map_type(type));
 			return NULL;
 		}
 		n->map_type = MAP_TYPE_UNUSED;
